=== modified file 'bzrlib/tests/test_weave.py'
--- bzrlib/tests/test_weave.py	2006-03-24 19:11:33 +0000
+++ bzrlib/tests/test_weave.py	2006-04-18 13:43:48 +0000
@@ -796,6 +796,11 @@
         self.log(result_text)
         self.assertEqualDiff(result_text, expected)
 
+    def test_weave_merge_conflicts(self):
+        # does weave merge properly handle plans that end with unchanged?
+        result = ''.join(Weave().weave_merge([('new-a', 'hello\n')]))
+        self.assertEqual(result, 'hello\n')
+
     def test_deletion_extended(self):
         """One side deletes, the other deletes more.
         """

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2006-04-18 06:44:59 +0000
+++ bzrlib/versionedfile.py	2006-04-18 13:43:48 +0000
@@ -437,6 +437,19 @@
         lines_a = []
         lines_b = []
         ch_a = ch_b = False
+
+        def outstanding_struct():
+            if not lines_a and not lines_b:
+                return
+            elif ch_a and not ch_b:
+                # one-sided change:
+                yield(lines_a,)
+            elif ch_b and not ch_a:
+                yield (lines_b,)
+            elif lines_a == lines_b:
+                yield(lines_a,)
+            else:
+                yield (lines_a, lines_b)
        
         # We previously considered either 'unchanged' or 'killed-both' lines
         # to be possible places to resynchronize.  However, assuming agreement
@@ -444,18 +457,8 @@
         for state, line in self.plan:
             if state == 'unchanged':
                 # resync and flush queued conflicts changes if any
-                if not lines_a and not lines_b:
-                    pass
-                elif ch_a and not ch_b:
-                    # one-sided change:
-                    yield(lines_a,)
-                elif ch_b and not ch_a:
-                    yield (lines_b,)
-                elif lines_a == lines_b:
-                    yield(lines_a,)
-                else:
-                    yield (lines_a, lines_b)
-
+                for struct in outstanding_struct():
+                    yield struct
                 lines_a = []
                 lines_b = []
                 ch_a = ch_b = False
@@ -478,7 +481,8 @@
             else:
                 assert state in ('irrelevant', 'ghost-a', 'ghost-b', 
                                  'killed-base', 'killed-both'), state
-
+        for struct in outstanding_struct():
+            yield struct
 
 class WeaveMerge(PlanWeaveMerge):
     """Weave merge that takes a VersionedFile and two versions as its input"""

